@@ -63,12 +63,15 @@ class Partition:
                 g.write(record)
                 g.write_new_line()
 
-    def count(self, outfile: str, verbose: bool = True):
+    def count(self, outfile: Optional[str] = None, verbose: bool = True) -> int:
         """Count
-        
+
         Args:
+            outfile (Optional[str], optional): output file to write to the value to if it is not None. if outfile is stdout we will print to stdout
             verbose (bool, optional): [description]. Defaults to True.
-            outfile (str): output file
+
+        Returns:
+            the number of records
         """
         if self.n_records is None:
             n_records = 0
@@ -78,9 +81,15 @@ class Partition:
             PartitionMetadata(self.path).write({"n_records": n_records})
             self.n_records = n_records
 
-        outfile = self._get_outfile(outfile)
-        with open(outfile, "w") as f:
-            f.write(str(self.n_records))
+        if outfile is not None:
+            if outfile == "stdout":
+                print(self.n_records)
+            else:
+                outfile = self._get_outfile(outfile)
+                with open(outfile, "w") as f:
+                    f.write(str(self.n_records))
+
+        return self.n_records
 
     def filter(self, fn: str, outfile: str, verbose: bool = True):
         """Filter function
