@@ -1,5 +1,6 @@
 import contextlib
 import glob
+from math import ceil
 from pathlib import Path
 from typing import Optional, List, Callable, Any
 
@@ -31,6 +32,27 @@ class ListPartition:
             size += part.n_records
         return size
 
+    def count(self, outfile: Optional[str] = None, verbose: bool = True):
+        """Count the number of records in all partitions
+
+        Args:
+            outfile (Optional[str], optional): output file to write to the value to if it is not None. if outfile is stdout we will print to stdout
+            verbose (bool): print the execution progress
+        """
+        if self.size is None:
+            for inpart in self.partitions:
+                inpart.count(verbose=verbose)
+            self.size = self._size()
+
+        if outfile is not None:
+            if outfile == "stdout":
+                print(self.size)
+            else:
+                with open(outfile, "w") as f:
+                    f.write(str(self.size))
+
+        return self.size
+
     def coalesce(self, outfile: str, records_per_partition: Optional[int] = None,
                  num_partitions: Optional[int] = None, verbose: bool = True):
         """The current partitions are coalesce into `num_partitions` partitions. If `num_partitions` is not specified, it will be figure out automatically
@@ -51,27 +73,40 @@ class ListPartition:
 
         if records_per_partition is None:
             assert num_partitions is not None
-            # TODO: cal the records_per_partition based on num_partitions
+            assert self.size is not None, "Cannot determine the records per partition based on number of partitions because of unknown size of partitions. Consider running partition.count or provide the `records_per_partition` parameter"
+            records_per_partition = ceil(self.size / num_partitions)
 
         part_counter = 0
 
         writer = None
+
+        record_counter = 0
+        last_record_counter = 0
+
         with (tqdm(total=self.size) if verbose else fake_tqdm()) as pbar:
             try:
                 writer = PartitionWriter(outfile % part_counter).open()
                 for inpart in self.partitions:
                     with inpart._open() as f:
                         for i, line in enumerate(f):
+                            writer.write(line)
+                            pbar.update(1)
+                            record_counter += 1
+
                             if (i + 1) % records_per_partition == 0:
                                 writer.close()
                                 part_counter += 1
                                 writer = PartitionWriter(outfile % part_counter).open()
-                            writer.write(line)
-                            pbar.update(1)
+                                last_record_counter = record_counter
+
             finally:
                 if writer is not None:
                     writer.close()
 
+                if last_record_counter == record_counter:
+                    # delete last empty file
+                    writer.delete()
+
     def concat(self, outfile: str, verbose: bool = True):
         """Concatenate partitions to one file
 
@@ -120,5 +155,7 @@ class ListPartition:
                         record = inpart.deser_fn(line)
                         accum = fn(record, accum)
                         pbar.update(1)
+
+            print(self.ser_fn(accum))
             g.write(self.ser_fn(accum))
             g.write_new_line()
